@@ -33,6 +33,7 @@
 #define __MLV__MLV_WINDOW_H__
 
 #include "MLV_color.h"
+#include "MLV_image.h"
 
 #ifdef __cplusplus
 extern "C" {
@@ -246,12 +247,23 @@ void MLV_free_window();
 /** \~french  
  * \brief Actualise l'affichage de la fenêtre.
  *
+ * Vois La fonction MLV_update_window 
+ *
  * Lorsque vous utilisez des fonctions de dessins, les différents changements
  * effectués ne sont pas visibles. Pour les afficher vous devez utiliser cette
  * fonction.
  */
 void MLV_actualise_window();
 
+/** \~french  
+ * \brief Met à jour l'affichage de la fenêtre.
+ *
+ * Lorsque vous utilisez des fonctions de dessins, les différents changements
+ * effectués ne sont pas visibles. Pour les afficher vous devez utiliser cette
+ * fonction.
+ */
+void MLV_update_window();
+
 /** \~french  
  * \brief Exécute la fonction de call back donnée en paramètre lorsque le système
  * envoie un signal d'arrêt, ou lorsque l'utilisateur clique sur la croix de la 
@@ -287,7 +299,6 @@ int MLV_get_desktop_height( );
  */
 int MLV_get_desktop_width( );
 
-
 #ifdef __cplusplus
 }
 #endif
