@@ -18,6 +18,14 @@
  *    along with this Library.  If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include <stdio.h>
+
+#include "platform.h"
+
+#ifdef OS_WINDOWS
+extern int asprintf (char **, const char *, ...);
+#endif
+
 #include "MLV_animation.h"
 #include "MLV_path.h"
 
@@ -27,7 +35,6 @@
 
 #include "MLV_xml.h"
 
-
 ////////////////////////////////////////////////
 //    Animation structures
 ///////////////////////////////////////////////
