@@ -48,5 +48,8 @@
 #endif
 
 SDL_Surface* create_surface( int width, int height );
+void get_pixel_on_image_unsafe( SDL_Surface* surface, int x, int y,
+	int* red, int* green, int* blue, int* alpha
+);
 
 #endif
