@@ -53,7 +53,11 @@ void MLV_wait_keyboard( MLV_Keyboard_button* sym, MLV_Keyboard_modifier* mod, in
 	);
 }
 
-int MLV_wait_keyboard_or_seconds( MLV_Keyboard_button* sym, MLV_Keyboard_modifier* mod, int* unicode, int seconds ){
+MLV_Event MLV_wait_keyboard_or_milliseconds(
+	MLV_Keyboard_button* sym, MLV_Keyboard_modifier* mod, int* unicode, 
+	int milliseconds 
+){
+	MLV_Event resultat = MLV_NONE;
 	MLV_Button_state state;
 
 	// We remove all existing event from the queue
@@ -66,35 +70,43 @@ int MLV_wait_keyboard_or_seconds( MLV_Keyboard_button* sym, MLV_Keyboard_modifie
 	int tmp_unicode;
 
 	//We wait for a new keyboard event
-	int resultat = 0;
 	while(
 		(
 			(
-				resultat = (
-					MLV_wait_event_or_seconds(
+				(
+					resultat = MLV_wait_event_or_milliseconds(
 						&tmp_sym, &tmp_mod, &tmp_unicode,
 						NULL, NULL,
 						NULL, NULL, NULL,
 						&state,
-						seconds - (MLV_get_time() - time)/1000
-					) != MLV_KEY
-				)
+						milliseconds - (MLV_get_time() - time)
+					)
+				) != MLV_KEY
 			) ||
 			( state != MLV_PRESSED )
 		) && (
-			(MLV_get_time() - time) < seconds*1000
+			(MLV_get_time() - time) < milliseconds
 		)
 	);
 
-	if( ! resultat && state == MLV_PRESSED ){
+	if( resultat == MLV_KEY && state == MLV_PRESSED ){
 		if( sym ) *sym = tmp_sym;
 		if( mod ) *mod = tmp_mod;
 		if( unicode ) *unicode = tmp_unicode;
+	}else{
+		resultat = MLV_NONE;
 	}
 
 	return resultat;
 }
 
+MLV_Event MLV_wait_keyboard_or_seconds(
+	MLV_Keyboard_button* sym, MLV_Keyboard_modifier* mod, int* unicode, 
+	int seconds 
+){
+	return MLV_wait_keyboard_or_milliseconds( sym, mod, unicode, seconds*1000 );
+}
+
 MLV_Keyboard_button MLV_convert_string_to_keyboard_button( const char* key_string ){
 
 	if(strcmp(key_string,"MLV_KEYBOARD_UNKNOWN") == 0){
