@@ -18,8 +18,8 @@
  *    along with this Library.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef __SDLKEYBOARDTOCHAR_H__
-#define  __SDLKEYBOARDTOCHAR_H__
+#ifndef __MLV__SDLKEYBOARDTOCHAR_H__
+#define __MLV__SDLKEYBOARDTOCHAR_H__
 
 #ifndef MEMORY_DEBUG
 #include <SDL/SDL.h>
