@@ -18,7 +18,22 @@
  *    along with this Library.  If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include <stdio.h>
+
+#include "platform.h"
+
+#ifdef OS_WINDOWS
+/* Get va_list.  */
+#if __STDC__ || defined __cplusplus || defined _MSC_VER
+# include <stdarg.h>
+#else
+# include <varargs.h>
+#endif
+extern int vasprintf (char **, const char *, va_list);
+#endif
+
 #include "MLV_text.h"
+#include "MLV_text_va.h"
 
 #include "platform.h"
 
@@ -55,18 +70,44 @@
 
 extern DataMLV* MLV_data;
 
-void MLV_get_size_of_text( const char *text, int *width, int *height ){
-	MLV_get_size_of_text_with_font( text, width, height, MLV_data->defaultFont );
+void MLV_get_size_of_text_va(
+	const char *text, int *width, int *height, va_list pile
+){
+	MLV_get_size_of_text_with_font_va(
+		text, width, height, MLV_data->defaultFont, pile
+	);
 }
 
-void MLV_get_size_of_text_with_font(
-	const char *text, int *width, int *height, const MLV_Font* font
+void MLV_get_size_of_text( const char *text, int *width, int *height, ... ){
+	va_list pile;
+	va_start( pile, height );
+	MLV_get_size_of_text_va( text, width, height, pile );
+	va_end( pile );
+}
+
+void MLV_get_size_of_text_with_font_va(
+	const char *text, int *width, int *height, const MLV_Font* font, 
+	va_list pile
 ){
-	if( strlen( text ) ){
-		TTF_SizeUTF8(font->font, text, width, height);
+	char* complete_text;
+	if( vasprintf( &complete_text, text, pile )==-1 ){
+		ERROR("Unexpected Error.");
+	}
+	if( strlen( complete_text ) ){
+		TTF_SizeUTF8(font->font, complete_text, width, height);
 	}else{
 		TTF_SizeUTF8(font->font, " ", width, height);
 	}
+	free( complete_text );
+}
+
+void MLV_get_size_of_text_with_font(
+	const char *text, int *width, int *height, const MLV_Font* font, ...
+){
+	va_list pile;
+	va_start( pile, font );
+	MLV_get_size_of_text_with_font_va( text, width, height, font, pile );
+	va_end( pile );
 }
 
 void init_font(){
@@ -151,74 +192,82 @@ void drawString(
 }
 
 
-void MLV_draw_text_on_image(
-	int x, int y, const char *text, MLV_Color color, MLV_Image* image
+void MLV_draw_text_on_image_va(
+	int x, int y, const char *text, MLV_Color color, MLV_Image* image,
+	va_list pile
 ){
-	MLV_draw_text_with_font_on_image(
-		x, y, text, MLV_data->defaultFont, color, image
+	MLV_draw_text_with_font_on_image_va(
+		x, y, text, MLV_data->defaultFont, color, image, pile
 	);
 }
 
+void MLV_draw_text_on_image(
+	int x, int y, const char *text, MLV_Color color, MLV_Image* image, ...
+){
+	va_list pile;
+	va_start( pile, image );
+	MLV_draw_text_on_image_va( x, y, text, color, image, pile );
+	va_end( pile );
+}
+
+void MLV_draw_text_with_font_on_image_va(
+	int x, int y, const char *text, const MLV_Font* font, MLV_Color color, 
+	MLV_Image* image, va_list pile
+){
+	char* complete_text;
+	if( vasprintf( &complete_text, text, pile )==-1 ){
+		ERROR("Unexpected Error.");
+	}
+	drawString( image->surface, x, y, complete_text, color, font->font );
+	free( complete_text );
+}
+
+
 void MLV_draw_text_with_font_on_image(
 	int x, int y, const char *text, const MLV_Font* font, MLV_Color color, 
-	MLV_Image* image
+	MLV_Image* image, ...
 ){
-	drawString( image->surface, x, y, text, color, font->font );
+	va_list pile;
+	va_start( pile, image );
+	MLV_draw_text_with_font_on_image_va( x, y, text, font, color, image, pile );
+	va_end( pile );
+}
+
+void MLV_draw_text_va(
+	int x, int y, const char *text, MLV_Color color, va_list pile
+){
+	MLV_draw_text_with_font_va(
+		x, y, text, MLV_data->defaultFont, color, pile
+	);
 }
 
 
+void MLV_draw_text(int x, int y, const char *text, MLV_Color color, ... ){
+	va_list pile;
+	va_start( pile, color );
+	MLV_draw_text_va( x, y, text, color, pile );
+	va_end( pile );
+}
 
-void MLV_draw_text(int x, int y, const char *text, MLV_Color color){
-	MLV_draw_text_with_font( x, y, text, MLV_data->defaultFont, color);
+void MLV_draw_text_with_font_va(
+	int x, int y, const char *text, const MLV_Font* font, MLV_Color color, 
+	va_list pile
+){
+	char* complete_text;
+	if( vasprintf( &complete_text, text, pile )==-1 ){
+		ERROR("Unexpected Error.");
+	}
+	drawString( MLV_data->screen, x, y, complete_text, color, font->font );
+	free( complete_text );
 }
 
 void MLV_draw_text_with_font(
-	int x, int y, const char *text, const MLV_Font* font, MLV_Color color
+	int x, int y, const char *text, const MLV_Font* font, MLV_Color color, ...
 ){
-	drawString( MLV_data->screen, x, y, text, color, font->font );
-}
-
-void MLV_draw_adapted_text_box(
-	int x, int y,
-	const char* message,
-	int sizeInterligne,
-	MLV_Color borderColor, MLV_Color textColor, MLV_Color backgroundColor,
-	MLV_Text_justification text_justification
-){
-	MLV_draw_adapted_text_box_with_font(
-		x, y, message, MLV_data->defaultFont, sizeInterligne,
-		borderColor, textColor, backgroundColor, 
-		text_justification
-	);
-}
-
-void MLV_draw_adapted_text_box_on_image(
-	int x, int y,
-	const char* message,
-	int sizeInterligne,
-	MLV_Color borderColor, MLV_Color textColor, MLV_Color backgroundColor,
-	MLV_Text_justification text_justification,
-	MLV_Image* image
-){
-	MLV_draw_adapted_text_box_with_font_on_image(
-		x, y, message, MLV_data->defaultFont, sizeInterligne,
-		borderColor, textColor, backgroundColor, 
-		text_justification,
-		image
-	);
-}
-
-int MLV_get_size_of_adapted_text_box(
-	const char* message,
-	int sizeInterligne,
-	int *result_width, int *result_height
-){
-	return MLV_get_size_of_adapted_text_box_with_font(
-		message,
-		MLV_data->defaultFont,
-		sizeInterligne,
-		result_width, result_height
-	);
+	va_list pile;
+	va_start( pile, color );
+	MLV_draw_text_with_font_va( x, y, text, font, color, pile );
+	va_end( pile );
 }
 
 int internal_draw_adapted_text_box_size_with_font(
@@ -367,23 +416,192 @@ void internal_draw_adapted_text_box_with_font_on_image(
 	MLV_FREE(copy, char);
 }
 
-void MLV_draw_adapted_text_box_with_font(
+void MLV_draw_adapted_text_box_with_font_va(
 	int x, int y,
 	const char* message,
 	const MLV_Font* font, 
 	int sizeInterligne,
 	MLV_Color borderColor, MLV_Color textColor, MLV_Color backgroundColor,
-	MLV_Text_justification text_justification
+	MLV_Text_justification text_justification,
+	va_list pile
 ){
+	char* complete_message;
+	if( vasprintf( &complete_message, message, pile )==-1 ){
+		ERROR("Unexpected Error.");
+	}
 	internal_draw_adapted_text_box_with_font_on_image(
 		x, y,
-		message,
+		complete_message,
 		font, 
 		sizeInterligne,
 		borderColor, textColor, backgroundColor,
 		text_justification,
 		MLV_data->screen	
 	);
+	free( complete_message );
+}
+
+void MLV_draw_adapted_text_box_va(
+	int x, int y,
+	const char* message,
+	int sizeInterligne,
+	MLV_Color borderColor, MLV_Color textColor, MLV_Color backgroundColor,
+	MLV_Text_justification text_justification, va_list pile
+){
+	MLV_draw_adapted_text_box_with_font_va(
+		x, y, message, MLV_data->defaultFont, sizeInterligne,
+		borderColor, textColor, backgroundColor, 
+		text_justification, pile
+	);
+}
+
+void MLV_draw_adapted_text_box(
+	int x, int y,
+	const char* message,
+	int sizeInterligne,
+	MLV_Color borderColor, MLV_Color textColor, MLV_Color backgroundColor,
+	MLV_Text_justification text_justification, ...
+){
+	va_list pile;
+	va_start( pile, text_justification );
+	MLV_draw_adapted_text_box_va(
+		x, y, message, sizeInterligne, borderColor, textColor, backgroundColor,
+		text_justification, pile
+	);
+	va_end( pile );
+}
+
+void MLV_draw_adapted_text_box_with_font_on_image_va(
+	int x, int y,
+	const char* message,
+	const MLV_Font* font, 
+	int sizeInterligne,
+	MLV_Color borderColor, MLV_Color textColor, MLV_Color backgroundColor,
+	MLV_Text_justification text_justification,
+	MLV_Image* image, va_list pile
+){
+	char* complete_message;
+	if( vasprintf( &complete_message, message, pile )==-1 ){
+		ERROR("Unexpected Error.");
+	}
+	internal_draw_adapted_text_box_with_font_on_image(
+		x, y,
+		complete_message,
+		font, 
+		sizeInterligne,
+		borderColor, textColor, backgroundColor,
+		text_justification,
+		image->surface
+	);
+	free( complete_message );
+}
+
+void MLV_draw_adapted_text_box_on_image_va(
+	int x, int y,
+	const char* message,
+	int sizeInterligne,
+	MLV_Color borderColor, MLV_Color textColor, MLV_Color backgroundColor,
+	MLV_Text_justification text_justification,
+	MLV_Image* image, va_list pile
+){
+	MLV_draw_adapted_text_box_with_font_on_image_va(
+		x, y, message, MLV_data->defaultFont, sizeInterligne,
+		borderColor, textColor, backgroundColor, 
+		text_justification,
+		image, pile
+	);
+}
+
+void MLV_draw_adapted_text_box_on_image(
+	int x, int y,
+	const char* message,
+	int sizeInterligne,
+	MLV_Color borderColor, MLV_Color textColor, MLV_Color backgroundColor,
+	MLV_Text_justification text_justification,
+	MLV_Image* image, ...
+){
+	va_list pile;
+	va_start( pile, image );
+	MLV_draw_adapted_text_box_on_image_va(
+		x, y, message, sizeInterligne,
+		borderColor, textColor, backgroundColor, 
+		text_justification,
+		image, pile
+	);
+	va_end( pile );
+}
+
+int MLV_get_size_of_adapted_text_box_with_font_va(
+	const char* message,
+	const MLV_Font* font, 
+	int sizeInterligne,
+	int *result_width, int *result_height,
+	va_list pile
+){
+	char* complete_message;
+	if( vasprintf( &complete_message, message, pile )==-1 ){
+		ERROR("Unexpected Error.");
+	}
+	char* copy = (char*) MLV_MALLOC( (strlen(complete_message)+1), char );
+	snprintf(copy, strlen(complete_message)+1, "%s", complete_message);
+	int result = internal_draw_adapted_text_box_size_with_font(
+		copy,
+		font, 
+		sizeInterligne,
+		result_width, result_height,
+		NULL
+	);
+	MLV_FREE(copy, char);
+	free( complete_message );
+	return result;
+}
+
+int MLV_get_size_of_adapted_text_box_va(
+	const char* message,
+	int sizeInterligne,
+	int *result_width, int *result_height,
+	va_list pile
+){
+	return MLV_get_size_of_adapted_text_box_with_font_va(
+		message,
+		MLV_data->defaultFont,
+		sizeInterligne,
+		result_width, result_height,
+		pile
+	);
+}
+
+int MLV_get_size_of_adapted_text_box(
+	const char* message,
+	int sizeInterligne,
+	int *result_width, int *result_height,
+	...
+){
+	int result;
+	va_list pile;
+	va_start( pile, result_height );
+	result = MLV_get_size_of_adapted_text_box_va(
+		message, sizeInterligne, result_width, result_height, pile
+	);
+	va_end( pile );
+	return result;
+}
+
+void MLV_draw_adapted_text_box_with_font(
+	int x, int y,
+	const char* message,
+	const MLV_Font* font, 
+	int sizeInterligne,
+	MLV_Color borderColor, MLV_Color textColor, MLV_Color backgroundColor,
+	MLV_Text_justification text_justification, ...
+){
+	va_list pile;
+	va_start( pile, text_justification );
+	MLV_draw_adapted_text_box_with_font_va(
+		x, y, message, font, sizeInterligne, borderColor, textColor, 
+		backgroundColor, text_justification, pile
+	);
+	va_end( pile );
 }
 
 void MLV_draw_adapted_text_box_with_font_on_image(
@@ -393,56 +611,33 @@ void MLV_draw_adapted_text_box_with_font_on_image(
 	int sizeInterligne,
 	MLV_Color borderColor, MLV_Color textColor, MLV_Color backgroundColor,
 	MLV_Text_justification text_justification,
-	MLV_Image* image
+	MLV_Image* image, ...
 ){
-	internal_draw_adapted_text_box_with_font_on_image(
-		x, y,
-		message,
-		font, 
-		sizeInterligne,
-		borderColor, textColor, backgroundColor,
-		text_justification,
-		image->surface
+	va_list pile;
+	va_start( pile, image );
+	MLV_draw_adapted_text_box_with_font_on_image_va(
+		x, y, message, font, sizeInterligne, borderColor, textColor, 
+		backgroundColor, text_justification, image, pile
 	);
+	va_end( pile );
 }
 
 int MLV_get_size_of_adapted_text_box_with_font(
 	const char* message,
 	const MLV_Font* font, 
 	int sizeInterligne,
-	int *result_width, int *result_height
+	int *result_width, int *result_height, ...
 ){
-	char* copy = (char*) MLV_MALLOC( (strlen(message)+1), char );
-	snprintf(copy, strlen(message)+1, "%s", message);
-	int result = internal_draw_adapted_text_box_size_with_font(
-		copy,
-		font, 
-		sizeInterligne,
-		result_width, result_height,
-		NULL
+	int result;
+	va_list pile;
+	va_start( pile, result_height );
+	result = MLV_get_size_of_adapted_text_box_with_font_va(
+		message, font, sizeInterligne, result_width, result_height, pile
 	);
-	MLV_FREE(copy, char);
+	va_end( pile );
 	return result;
 }
 
-
-void MLV_draw_text_box( 
-	int x, int y, 
-	int width, int height, 
-	const char* message , 
-	int sizeInterligne,
-	MLV_Color borderColor, MLV_Color textColor, MLV_Color backgroundColor,
-	MLV_Text_justification text_justification,
-	MLV_Horizontal_position horizontal_position,
-	MLV_Vertical_position vertical_position
-){
-	MLV_draw_text_box_with_font( 
-		x, y, width, height, message , MLV_data->defaultFont, sizeInterligne,
-		borderColor, textColor, backgroundColor, text_justification,
-		horizontal_position, vertical_position
-	);
-}
-
 void internal_draw_text_box_with_font_on_image( 
 	int x, int y, 
 	int width, int height, 
@@ -525,6 +720,76 @@ void internal_draw_text_box_with_font_on_image(
 	MLV_FREE(copy, char);
 }
 
+void MLV_draw_text_box_with_font_va( 
+	int x, int y, 
+	int width, int height, 
+	const char* message , 
+	const MLV_Font* font, 
+	int sizeInterligne,
+	MLV_Color borderColor, MLV_Color textColor, MLV_Color backgroundColor,
+	MLV_Text_justification text_justification,
+	MLV_Horizontal_position horizontal_position,
+	MLV_Vertical_position vertical_position,
+	va_list pile
+){
+	char* complete_message;
+	if( vasprintf( &complete_message, message, pile )==-1 ){
+		ERROR("Unexpected Error.");
+	}
+	internal_draw_text_box_with_font_on_image( 
+		x, y, 
+		width, height, 
+		complete_message, 
+		font, 
+		sizeInterligne,
+		borderColor, textColor, backgroundColor,
+		text_justification,
+		horizontal_position,
+		vertical_position,
+		MLV_data->screen	
+	);
+	free( complete_message );
+}
+
+void MLV_draw_text_box_va( 
+	int x, int y, 
+	int width, int height, 
+	const char* message , 
+	int sizeInterligne,
+	MLV_Color borderColor, MLV_Color textColor, MLV_Color backgroundColor,
+	MLV_Text_justification text_justification,
+	MLV_Horizontal_position horizontal_position,
+	MLV_Vertical_position vertical_position,
+	va_list pile
+){
+	MLV_draw_text_box_with_font_va( 
+		x, y, width, height, message , MLV_data->defaultFont, sizeInterligne,
+		borderColor, textColor, backgroundColor, text_justification,
+		horizontal_position, vertical_position, pile
+	);
+}
+
+void MLV_draw_text_box( 
+	int x, int y, 
+	int width, int height, 
+	const char* message , 
+	int sizeInterligne,
+	MLV_Color borderColor, MLV_Color textColor, MLV_Color backgroundColor,
+	MLV_Text_justification text_justification,
+	MLV_Horizontal_position horizontal_position,
+	MLV_Vertical_position vertical_position,
+	...
+){
+	va_list pile;
+	va_start( pile, vertical_position );
+	MLV_draw_text_box_va( 
+		x, y, width, height, message , sizeInterligne, borderColor, textColor, 
+		backgroundColor, text_justification, horizontal_position,
+		 vertical_position, pile
+	);
+	va_end( pile );
+}
+
 void MLV_draw_text_box_with_font( 
 	int x, int y, 
 	int width, int height, 
@@ -534,23 +799,20 @@ void MLV_draw_text_box_with_font(
 	MLV_Color borderColor, MLV_Color textColor, MLV_Color backgroundColor,
 	MLV_Text_justification text_justification,
 	MLV_Horizontal_position horizontal_position,
-	MLV_Vertical_position vertical_position
+	MLV_Vertical_position vertical_position,
+	...
 ){
-	internal_draw_text_box_with_font_on_image( 
-		x, y, 
-		width, height, 
-		message, 
-		font, 
-		sizeInterligne,
-		borderColor, textColor, backgroundColor,
-		text_justification,
-		horizontal_position,
-		vertical_position,
-		MLV_data->screen	
+	va_list pile;
+	va_start( pile, vertical_position );
+	MLV_draw_text_box_with_font_va( 
+		x, y, width, height, message, font, sizeInterligne,
+		borderColor, textColor,  backgroundColor, text_justification, 
+		horizontal_position, vertical_position, pile
 	);
+	va_end( pile );
 }
 
-void MLV_draw_text_box_with_fonti_on_image( 
+void MLV_draw_text_box_with_font_on_image_va( 
 	int x, int y, 
 	int width, int height, 
 	const char* message , 
@@ -560,12 +822,17 @@ void MLV_draw_text_box_with_fonti_on_image(
 	MLV_Text_justification text_justification,
 	MLV_Horizontal_position horizontal_position,
 	MLV_Vertical_position vertical_position,
-	MLV_Image* image
+	MLV_Image* image,
+	va_list pile
 ){
+	char* complete_message;
+	if( vasprintf( &complete_message, message, pile )==-1 ){
+		ERROR("Unexpected Error.");
+	}
 	internal_draw_text_box_with_font_on_image( 
 		x, y, 
 		width, height, 
-		message, 
+		complete_message, 
 		font, 
 		sizeInterligne,
 		borderColor, textColor, backgroundColor,
@@ -574,9 +841,73 @@ void MLV_draw_text_box_with_fonti_on_image(
 		vertical_position,
 		image->surface
 	);
+	free( complete_message );
+}
+
+void MLV_draw_text_box_with_font_on_image( 
+	int x, int y, 
+	int width, int height, 
+	const char* message , 
+	MLV_Font* font, 
+	int sizeInterligne,
+	MLV_Color borderColor, MLV_Color textColor, MLV_Color backgroundColor,
+	MLV_Text_justification text_justification,
+	MLV_Horizontal_position horizontal_position,
+	MLV_Vertical_position vertical_position,
+	MLV_Image* image,
+	...
+){
+	va_list pile;
+	va_start( pile, image );
+	MLV_draw_text_box_with_font_on_image_va( 
+		x, y, width, height, message, font, sizeInterligne, borderColor, 
+		textColor, backgroundColor, text_justification, horizontal_position, 
+		vertical_position, image, pile
+	);
+	va_end( pile );
+}
+
+void MLV_draw_text_box_on_image_va( 
+	int x, int y, 
+	int width, int height, 
+	const char* message , 
+	int sizeInterligne,
+	MLV_Color borderColor, MLV_Color textColor, MLV_Color backgroundColor,
+	MLV_Text_justification text_justification,
+	MLV_Horizontal_position horizontal_position,
+	MLV_Vertical_position vertical_position,
+	MLV_Image* image,
+	va_list pile
+){
+	MLV_draw_text_box_with_font_on_image_va( 
+		x, y, width, height, message, MLV_data->defaultFont, sizeInterligne, 
+		borderColor, textColor, backgroundColor, text_justification, 
+		horizontal_position, vertical_position, image, pile
+	);
 }
 
 
+void MLV_draw_text_box_on_image( 
+	int x, int y, 
+	int width, int height, 
+	const char* message , 
+	int sizeInterligne,
+	MLV_Color borderColor, MLV_Color textColor, MLV_Color backgroundColor,
+	MLV_Text_justification text_justification,
+	MLV_Horizontal_position horizontal_position,
+	MLV_Vertical_position vertical_position,
+	MLV_Image* image,
+	...
+){
+	va_list pile;
+	va_start( pile, image );
+	MLV_draw_text_box_on_image_va( 
+		x, y, width, height, message, sizeInterligne, borderColor, textColor, 
+		backgroundColor, text_justification, horizontal_position,
+		vertical_position, image, pile
+	);
+	va_end( pile );
+}
 
 char* MLV_convert_unicode_to_string( int unicode ){
 	gunichar v = unicode;
