@@ -1,7 +1,7 @@
 /*
  *   This file is part of the MLV Library.
  *
- *   Copyright (C) 2010,2011,2012 Adrien Boussicault, Marc Zipstein
+ *   Copyright (C) 2010,2011,2012,2016 Adrien Boussicault, Marc Zipstein
  *
  *
  *    This Library is free software: you can redistribute it and/or modify
@@ -25,12 +25,14 @@
 #include "config.h"
 
 #include "text.h"
+#include "window.h"
 
 #include "input_box.h"
 #include "MLV_color.h"
 #include "MLV_audio.h"
 #include <stdio.h>
 #include <stdlib.h>
+#include <assert.h>
 
 #include "platform.h"
 
@@ -101,7 +103,21 @@ MLV Library, create a new window with the MLV_create_window function."
 	MLV_free_font( MLV_data->defaultFont );
 }
 
+void intialize_post_production_images(){
+	MLV_data->post_screen = MLV_data->screen;
+	MLV_data->post_production_image = MLV_create_image(
+		MLV_data->width, MLV_data->height
+	);
+	MLV_data->screen = create_surface(  MLV_data->width, MLV_data->height );
+}
 
+void free_post_production_images(){
+	SDL_FreeSurface( MLV_data->screen );
+	MLV_free_image( MLV_data->post_production_image );
+	MLV_data->post_production_image = NULL;
+	MLV_data->screen = MLV_data->post_screen;
+	MLV_data->post_screen = NULL;
+}
 
 /**************************************************************************/
 /* Creation d'un fenetre graphique                                        */
@@ -109,6 +125,11 @@ MLV Library, create a new window with the MLV_create_window function."
 void initialise_graphic_window(
 	unsigned int width, unsigned int height, int full_screen_is_required
 ){
+	int we_need_to_reinitialize_post_screen = 0;
+	if( MLV_data->post_screen ){
+		free_post_production_images();
+		we_need_to_reinitialize_post_screen = 1;
+	}
 	#if defined( OS_ANDROID )
 		Uint32 video_mode_flags = SDL_SWSURFACE | SDL_SRCALPHA;
 	#else
@@ -134,7 +155,7 @@ void initialise_graphic_window(
 	MLV_data->rectangle.w = width;
 	MLV_data->rectangle.h = height;
 	if( MLV_data->save_screen ){
-		SDL_FreeSurface( MLV_data->screen );
+		SDL_FreeSurface( MLV_data->save_screen );
 	}
 	MLV_data->save_screen = create_surface( width, height ); // do we have to use SDL_ALPHA_OPAQUE here ?
 	if ( MLV_data->screen == NULL ){
@@ -142,11 +163,17 @@ void initialise_graphic_window(
 		exit(1);
 	}
 
+
 	/**************************************************************************/
 	/* Initialisation de la couleur du fond de la fenetre en noir.            */
 	/**************************************************************************/
-	MLV_draw_filled_rectangle(0,0,width,height,MLV_COLOR_BLACK);
+	MLV_data->ground_color = MLV_COLOR_BLACK;
+	MLV_draw_filled_rectangle(0,0,width,height, MLV_data->ground_color);
 	MLV_actualise_window();
+
+	if( we_need_to_reinitialize_post_screen ){
+		intialize_post_production_images();
+	}
 }
 
 
@@ -188,6 +215,39 @@ void initialise_size_of_desktop(){
 	}
 }
 
+void MLV_register_a_post_producter( void ( *post_producter )( MLV_Image* ) ){
+	if( ! MLV_data->post_screen ){
+		intialize_post_production_images();
+	}
+	MLV_data->post_producters = MLV_prepend_list(
+		MLV_data->post_producters,
+		(void*) post_producter
+	);
+}
+
+void MLV_unregister_a_post_producter( void ( *post_producter )( MLV_Image* ) ){
+	assert( MLV_data->post_producters );
+	MLV_data->post_producters = MLV_remove_list(
+		MLV_data->post_producters, (void*) post_producter
+	);
+	if( ! MLV_data->post_producters ){
+		free_post_production_images();
+	}
+}
+
+void unregister_all_producters(){
+	if( MLV_data->post_producters ){
+		MLV_free_list( MLV_data->post_producters );
+		free_post_production_images();
+	}
+}
+
+void init_post_producter_infrastructure(){
+	MLV_data->post_screen = NULL;
+	MLV_data->post_producters = NULL;
+	MLV_data->post_production_image = NULL;
+}
+
 void MLV_create_window_with_default_font(
 	const char* window_name, const char* icone_name, 
 	unsigned int width, unsigned int height,
@@ -202,6 +262,8 @@ void MLV_create_window_with_default_font(
 	MLV_data = MLV_MALLOC( 1, DataMLV );
 	MLV_data->screen = NULL;
 	MLV_data->save_screen = NULL;
+	MLV_data->leonardo = NULL;
+	init_post_producter_infrastructure();
 
 	/**************************************************************************/
 	/* Initialisation de la libriaire SDL pour l'uilisation de la video et du */
@@ -234,6 +296,11 @@ void MLV_create_window_with_default_font(
 	/**************************************************************************/
 	init_font();
 	
+	/**************************************************************************/
+	/* Initialisation de tortue Leonardo, la mascotte de MLV                  */
+	/**************************************************************************/
+	init_leonardo_turtle();
+
 	/**************************************************************************/
 	/* Création d'une font par default                                        */
 	/**************************************************************************/
@@ -335,6 +402,8 @@ void MLV_free_window(){
 	if( ! MLV_data ){
 		ERROR("No window has been created.");
 	}
+	free_leonardo_turtle();
+	unregister_all_producters();
 	SDL_FreeSurface(MLV_data->screen);
 	SDL_FreeSurface(MLV_data->save_screen);
 	free_default_font();
@@ -345,11 +414,51 @@ void MLV_free_window(){
 	quit_input_box_mechanism();
 }
 
+void draw_producter( void* data, void* user_data ){
+	void ( *post_producter )( MLV_Image* ) = (void (*)( MLV_Image* )) data; 
+	MLV_Image* image = (MLV_Image*) user_data;
+	post_producter( image );
+}
+
+void prepare_post_production_image(){
+	MLV_draw_filled_rectangle_on_image(
+		0, 0, MLV_get_window_width( ), MLV_get_window_height( ), 
+		MLV_data->ground_color, 
+		MLV_data->post_production_image
+	);
+
+	MLV_set_alpha_on_image(
+		MLV_ALPHA_TRANSPARENT, MLV_data->post_production_image
+	);
+
+	MLV_foreach_list(
+		MLV_data->post_producters, draw_producter,  
+		MLV_data->post_production_image
+	);
+}
+
+
 void MLV_update_window(){
 	if( (! MLV_data ) || (! MLV_data->screen) ){
 		ERROR("A window can't be displayed whitout being created.");
 	}
-	SDL_Flip(MLV_data->screen);
+	if( ! MLV_data->post_producters ){
+		SDL_Flip(MLV_data->screen);
+	}else{
+		prepare_post_production_image();
+		boxColor(
+			MLV_data->post_screen, 0, 0, MLV_data->width-1, MLV_data->height-1, 
+			MLV_data->ground_color
+		);
+		SDL_BlitSurface(
+			MLV_data->screen, NULL, MLV_data->post_screen, &MLV_data->rectangle
+		);
+		SDL_BlitSurface(
+			MLV_data->post_production_image->surface, NULL, 
+			MLV_data->post_screen, &MLV_data->rectangle
+		);
+		SDL_Flip(MLV_data->post_screen);
+	}
 }
 
 #ifndef OS_APPLE  // Hack to compile with MAC OS 10.9 (maverick)
